==> werkout-server-1.2.6.tgz: package/lib/reservationManager.js <==
const jet = require('node-jet')
const { createDataBroker } = require('./dataBroker')
const { createQueueManager } = require('./queueManager')
const { createRequest } = require('./request')
const {
  createPartnerManager,
  createUserManager
} = require('./resourceManagers')
const { parseResourcePath } = require('./jetHelpers')

exports.createReservationManager = async function (peer, daemon) {
  const dataBroker = createDataBroker(peer)

  // Pass the callback into the constructor of queueManager
  // so that we don't have to pass it the peer
  const queueManager = createQueueManager()

  const resourceManagers = {
    partners: createPartnerManager(peer, queueManager.onResourceProvided),
    users: createUserManager(queueManager.onResourceProvided)
  }

  function addResource ({ type, data }) {
    dataBroker.startTransaction(db => resourceManagers[type].add(db, data))
  }

  function releaseResource ({ type, id }) {
    console.log(`Releasing resource of type ${type} and id of ${id}`)
    dataBroker.startTransaction(db => resourceManagers[type].release(db, id))
  }

  function requestResources (rawRequest) {
    console.log('Request received from', rawRequest.from)
    const request = createRequest(peer, rawRequest)
    // Timeout the request after 10 minutes
    request.timeout.promise.then(async () => {
      await cancelRequest(request.from)
      request.cancel()
    })
    // Start transaction to prevent other actions on the queue and data
    dataBroker.startTransaction(db => {
      // Push converted request into the queue
      queueManager.push(request)
      // Process queue
      return queueManager.onResourceProvided(db)
    })
  }

  // Create jet Methods
  const addResourceMethod = new jet.Method(
    '/werkout-server/methods/addResource'
  ).on('call', addResource)

  const releaseResourceMethod = new jet.Method(
    '/werkout-server/methods/releaseResource'
  ).on('call', releaseResource)

  const requestResourcesMethod = new jet.Method(
    '/werkout-server/methods/requestResources'
  ).on('call', requestResources)

  function cancelRequest (peerId) {
    dataBroker.startTransaction(async db => {
      // Remove any requests in the queue belonging to the peer
      await queueManager.removeFromQueue(peerId)

      // Find all resources reserved by peer that disconnected
      const query = {
        valueField: {
          reservedBy: {
            equals: peerId
          }
        }
      }
      const reservedByPeer = await db.get(query)

      if (reservedByPeer && reservedByPeer.length) {
        await Promise.all(
          reservedByPeer.map(resource => {
            // Get the type of resource and resource id from the path
            const { type, id } = parseResourcePath(resource.path)
            return resourceManagers[type].release(db, id)
          })
        )
      }
    })
  }

  // Add listeners to daemon
  daemon.on('disconnect', peer => {
    cancelRequest(peer.id)
  })

  return Promise.all([
    // Add methods
    peer.add(addResourceMethod),
    peer.add(releaseResourceMethod),
    peer.add(requestResourcesMethod)
  ])
}

==> werkout-server-1.4.0.tgz: package/lib/reservationManager.js <==
const { logger } = require('./logger')
const jet = require('node-jet')
const { createDataBroker } = require('./dataBroker')
const { createQueueManager } = require('./queueManager')
const { createRequest } = require('./request')
const {
  createPartnerManager,
  createUserManager
} = require('./resourceManagers')
const { parseResourcePath } = require('./jetHelpers')

exports.createReservationManager = async function (peer, daemon) {
  const dataBroker = createDataBroker(peer)

  // Pass the callback into the constructor of queueManager
  // so that we don't have to pass it the peer
  const queueManager = createQueueManager()

  const resourceManagers = {
    partners: createPartnerManager(peer, queueManager.onResourceProvided),
    users: createUserManager(queueManager.onResourceProvided)
  }

  function addResource ({ type, data }) {
    dataBroker.startTransaction(db => resourceManagers[type].add(db, data))
  }

  function releaseResource ({ type, id }) {
    logger.info(`Releasing resource of type ${type} and id of ${id}`)
    dataBroker.startTransaction(db => resourceManagers[type].release(db, id))
  }

  function requestResources (rawRequest) {
    logger.info('Request received from', rawRequest.from)
    const request = createRequest(peer, rawRequest)
    // Timeout the request after 10 minutes
    request.timeout.promise.then(async () => {
      await cancelRequest(request.from)
      request.cancel()
    })
    // Start transaction to prevent other actions on the queue and data
    dataBroker.startTransaction(db => {
      // Push converted request into the queue
      queueManager.push(request)
      // Process queue
      return queueManager.onResourceProvided(db)
    })
  }

  // Create jet Methods
  const addResourceMethod = new jet.Method(
    '/werkout-server/methods/addResource'
  ).on('call', addResource)

  const releaseResourceMethod = new jet.Method(
    '/werkout-server/methods/releaseResource'
  ).on('call', releaseResource)

  const requestResourcesMethod = new jet.Method(
    '/werkout-server/methods/requestResources'
  ).on('call', requestResources)

  function cancelRequest (peerId) {
    dataBroker.startTransaction(async db => {
      // Remove any requests in the queue belonging to the peer
      await queueManager.removeFromQueue(peerId)

      // Find all resources reserved by peer that disconnected
      const query = {
        valueField: {
          reservedBy: {
            equals: peerId
          }
        }
      }
      const reservedByPeer = await db.get(query)

      if (reservedByPeer && reservedByPeer.length) {
        await Promise.all(
          reservedByPeer.map(resource => {
            // Get the type of resource and resource id from the path
            const { type, id } = parseResourcePath(resource.path)
            return resourceManagers[type].release(db, id)
          })
        )
      }
    })
  }

  // Add listeners to daemon
  daemon.on('disconnect', peer => {
    cancelRequest(peer.id)
  })

  return Promise.all([
    // Add methods
    peer.add(addResourceMethod),
    peer.add(releaseResourceMethod),
    peer.add(requestResourcesMethod)
  ])
}
